summaryrefslogtreecommitdiff
path: root/src/map/atcommand.c
diff options
context:
space:
mode:
authoramber <amber@54d463be-8e91-2dee-dedb-b68131a5f0ec>2004-11-26 07:33:21 +0000
committeramber <amber@54d463be-8e91-2dee-dedb-b68131a5f0ec>2004-11-26 07:33:21 +0000
commit952d9ecd0f059e9801c7344154df83e7a7110ead (patch)
tree17cac8c6203b79330851ee620dd6431c9ce1f62e /src/map/atcommand.c
parentdd86930bcace0da25bc2963fbfc1c5c3d2787455 (diff)
downloadhercules-952d9ecd0f059e9801c7344154df83e7a7110ead.tar.gz
hercules-952d9ecd0f059e9801c7344154df83e7a7110ead.tar.bz2
hercules-952d9ecd0f059e9801c7344154df83e7a7110ead.tar.xz
hercules-952d9ecd0f059e9801c7344154df83e7a7110ead.zip
Make it work a bit better with win32
git-svn-id: https://rathena.svn.sourceforge.net/svnroot/rathena/athena@366 54d463be-8e91-2dee-dedb-b68131a5f0ec
Diffstat (limited to 'src/map/atcommand.c')
-rw-r--r--src/map/atcommand.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/map/atcommand.c b/src/map/atcommand.c
index 4020b82e3..34bf0150d 100644
--- a/src/map/atcommand.c
+++ b/src/map/atcommand.c
@@ -568,10 +568,10 @@ char * job_name(int class) {
}
/*==========================================
* str_lower (replace strlwr, non ANSI function that doesn't exist in all C compilator)
*------------------------------------------
*/
-char *str_lower(char *str)
+char *estr_lower(char *str)
{
int i;
@@ -7570,7 +7570,7 @@ atcommand_uptime(
minutes = seconds/minute;
seconds -= (seconds/minute>0)?(seconds/minute)*minute:0;
- snprintf(output, sizeof(output), msg_table[245], days, hours, minutes, seconds);
+ snprintf(output, sizeof(output), msg_table[245], days, hours, minutes, seconds);
clif_displaymessage(fd,output);
return 0;
}
@@ -7654,14 +7654,14 @@ atcommand_petid(const int fd, struct map_session_data* sd,
return -1;
if (sscanf(message, "%99s", searchtext) < 1)
return -1;
- str_lower(searchtext);
+ estr_lower(searchtext);
snprintf(temp0, sizeof(temp0), "Search results for: %s", searchtext);
clif_displaymessage(fd,temp0);
while (i < MAX_PET_DB) {
strcpy(temp1,pet_db[i].name);
- strcpy(temp1, str_lower(temp1));
+ strcpy(temp1, estr_lower(temp1));
strcpy(temp0,pet_db[i].jname);
- strcpy(temp0, str_lower(temp1));
+ strcpy(temp0, estr_lower(temp1));
if (strstr(temp1, searchtext) || strstr(temp0, searchtext) ) {
snprintf(temp0, sizeof(temp0), "ID: %i -- Name: %s", pet_db[i].class,
pet_db[i].jname);
@@ -568,10 +568,10 @@ char * job_name(int class) {
}
/*==========================================
- * str_lower (replace strlwr, non ANSI function that doesn't exist in all C compilator)
+ * estr_lower (replace strlwr, non ANSI function that doesn't exist in all C compilator)
*------------------------------------------
*/